Method: CloudFiles::Container#create_object

Defined in:
lib/vendor/cloudfiles-1.3.0/cloudfiles/container.rb

#create_object(objectname, make_path = false) ⇒ Object

Creates a new CloudFiles::StorageObject in the current container.

If an object with the specified name exists in the current container, that object will be returned. Otherwise, an empty new object will be returned.

Passing in the optional make_path argument as true will create zero-byte objects to simulate a filesystem path to the object, if an objectname with path separators (“/path/to/myfile.mp3”) is supplied. These path objects can be used in the Container.objects method.



207
208
209
# File 'lib/vendor/cloudfiles-1.3.0/cloudfiles/container.rb', line 207

def create_object(objectname,make_path = false)
  CloudFiles::StorageObject.new(self,objectname,false,make_path)
end